:github_url: https://github.com/stephane-caron/pink/tree/main/doc/barriers.rst

.. _Barriers:

********
Barriers
********

Definition
==========

.. automodule:: pink.barriers.barrier
    :members:

Position barrier
================

.. automodule:: pink.barriers.position_barrier
    :members:

Body Spherical barrier
======================

.. automodule:: pink.barriers.body_spherical_barrier
    :members:

Whole Body Collision Avoidance
==============================

.. automodule:: pink.barriers.self_collision_barrier
    :members: